Uses of Class org.openqa.selenium.server.browserlaunchers.SafariCustomProfileLauncher (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.browserlaunchers.SafariCustomProfileLauncher

Packages that use SafariCustomProfileLauncher
org.openqa.selenium.server.browserlaunchers | Provides classes to launch and kill browsers.

Uses of SafariCustomProfileLauncher in org.openqa.selenium.server.browserlaunchers

Subclasses of SafariCustomProfileLauncher in org.openqa.selenium.server.browserlaunchers
`class` | `ProxyInjectionSafariCustomProfileLauncher` launcher for Safari under proxy injection mode In proxy injection mode, the selenium server is a proxy for all traffic from the browser, not just traffic going to selenium-server URLs.
`class` | `SafariFileBasedLauncher`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.